Function widget
pub fn widget<T>(operation: impl Operation<T> + 'static) -> Task<T>where
T: Send + 'static,Expand description
Creates a new Task that runs the given widget::Operation and produces
its output.
pub fn widget<T>(operation: impl Operation<T> + 'static) -> Task<T>where
T: Send + 'static,Creates a new Task that runs the given widget::Operation and produces
its output.